@@ -1,22 +1,30 @@
+# frozen_string_literal: true
+
 # Puppet provider for mysql
 class Puppet::Provider::Mysql < Puppet::Provider
   # Without initvars commands won't work.
   initvars
 
   # Make sure we find mysql commands on CentOS and FreeBSD
-  ENV['PATH'] = ENV['PATH'] + ':/usr/libexec:/usr/local/libexec:/usr/local/bin'
+  ENV['PATH'] = "#{ENV.fetch('PATH', nil)}:/usr/libexec:/usr/local/libexec:/usr/local/bin"
   ENV['LD_LIBRARY_PATH'] = [
-    ENV['LD_LIBRARY_PATH'],
+    ENV.fetch('LD_LIBRARY_PATH', nil),
     '/usr/lib',
     '/usr/lib64',
     '/opt/rh/rh-mysql56/root/usr/lib',
     '/opt/rh/rh-mysql56/root/usr/lib64',
     '/opt/rh/rh-mysql57/root/usr/lib',
     '/opt/rh/rh-mysql57/root/usr/lib64',
+    '/opt/rh/rh-mysql80/root/usr/lib',
+    '/opt/rh/rh-mysql80/root/usr/lib64',
     '/opt/rh/rh-mariadb100/root/usr/lib',
     '/opt/rh/rh-mariadb100/root/usr/lib64',
     '/opt/rh/rh-mariadb101/root/usr/lib',
     '/opt/rh/rh-mariadb101/root/usr/lib64',
+    '/opt/rh/rh-mariadb102/root/usr/lib',
+    '/opt/rh/rh-mariadb102/root/usr/lib64',
+    '/opt/rh/rh-mariadb103/root/usr/lib',
+    '/opt/rh/rh-mariadb103/root/usr/lib64',
     '/opt/rh/mysql55/root/usr/lib',
     '/opt/rh/mysql55/root/usr/lib64',
     '/opt/rh/mariadb55/root/usr/lib',
@@ -63,10 +71,10 @@ class Puppet::Provider::Mysql < Puppet::Provider
   end
 
   def self.mysqld_version
-    # note: be prepared for '5.7.6-rc-log' etc results
+    # NOTE: be prepared for '5.7.6-rc-log' etc results
     #       versioncmp detects 5.7.6-log to be newer then 5.7.6
     #       this is why we need the trimming.
-    mysqld_version_string.scan(%r{\d+\.\d+\.\d+}).first unless mysqld_version_string.nil?
+    mysqld_version_string&.scan(%r{\d+\.\d+\.\d+})&.first
   end
 
   def mysqld_version
@@ -74,13 +82,21 @@ class Puppet::Provider::Mysql < Puppet::Provider
   end
 
   def self.newer_than(forks_versions)
-    forks_versions.keys.include?(mysqld_type) && Puppet::Util::Package.versioncmp(mysqld_version, forks_versions[mysqld_type]) >= 0
+    forks_versions.key?(mysqld_type) && Puppet::Util::Package.versioncmp(mysqld_version, forks_versions[mysqld_type]) >= 0
   end
 
   def newer_than(forks_versions)
     self.class.newer_than(forks_versions)
   end
 
+  def self.older_than(forks_versions)
+    forks_versions.key?(mysqld_type) && Puppet::Util::Package.versioncmp(mysqld_version, forks_versions[mysqld_type]).negative?
+  end
+
+  def older_than(forks_versions)
+    self.class.older_than(forks_versions)
+  end
+
   def defaults_file
     self.class.defaults_file
   end
@@ -89,16 +105,16 @@ class Puppet::Provider::Mysql < Puppet::Provider
     if type.eql? 'system'
       if File.file?("#{Facter.value(:root_home)}/.mylogin.cnf")
         ENV['MYSQL_TEST_LOGIN_FILE'] = "#{Facter.value(:root_home)}/.mylogin.cnf"
-        mysql_raw([system_database, '-e', text_of_sql].flatten.compact)
+        mysql_raw([system_database, '-e', text_of_sql].flatten.compact).scrub
       else
-        mysql_raw([defaults_file, system_database, '-e', text_of_sql].flatten.compact)
+        mysql_raw([defaults_file, system_database, '-e', text_of_sql].flatten.compact).scrub
       end
     elsif type.eql? 'regular'
       if File.file?("#{Facter.value(:root_home)}/.mylogin.cnf")
         ENV['MYSQL_TEST_LOGIN_FILE'] = "#{Facter.value(:root_home)}/.mylogin.cnf"
-        mysql_raw(['-NBe', text_of_sql].flatten.compact)
+        mysql_raw(['-NBe', text_of_sql].flatten.compact).scrub
       else
-        mysql_raw([defaults_file, '-NBe', text_of_sql].flatten.compact)
+        mysql_raw([defaults_file, '-NBe', text_of_sql].flatten.compact).scrub
       end
     else
       raise Puppet::Error, _("#mysql_caller: Unrecognised type '%{type}'" % { type: type })
@@ -129,7 +145,7 @@ class Puppet::Provider::Mysql < Puppet::Provider
     table_string = ''
 
     # We can't escape *.* so special case this.
-    table_string << if table == '*.*'
+    table_string += if table == '*.*'
                       '*.*'
                     # Special case also for FUNCTIONs and PROCEDUREs
                     elsif table.start_with?('FUNCTION ', 'PROCEDURE ')
@@ -142,9 +158,10 @@ class Puppet::Provider::Mysql < Puppet::Provider
 
   def self.cmd_privs(privileges)
     return 'ALL PRIVILEGES' if privileges.include?('ALL')
+
     priv_string = ''
     privileges.each do |priv|
-      priv_string << "#{priv}, "
+      priv_string += "#{priv}, "
     end
     # Remove trailing , from the last element.
     priv_string.sub(%r{, $}, '')
@@ -154,7 +171,7 @@ class Puppet::Provider::Mysql < Puppet::Provider
   def self.cmd_options(options)
     option_string = ''
     options.each do |opt|
-      option_string << ' WITH GRANT OPTION' if opt == 'GRANT'
+      option_string += ' WITH GRANT OPTION' if opt == 'GRANT'
     end
     option_string
   end
