@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require File.expand_path(File.join(File.dirname(__FILE__), '..', 'mysql'))
 Puppet::Type.type(:mysql_datadir).provide(:mysql, parent: Puppet::Provider::Mysql) do
   desc 'manage data directories for mysql instances'
@@ -6,9 +8,11 @@ Puppet::Type.type(:mysql_datadir).provide(:mysql, parent: Puppet::Provider::Mysq
 
   # Make sure we find mysqld on CentOS and mysql_install_db on Gentoo and Solaris 11
   ENV['PATH'] = [
-    ENV['PATH'],
+    ENV.fetch('PATH', nil),
     '/usr/libexec',
     '/usr/share/mysql/scripts',
+    '/opt/rh/rh-mysql80/root/usr/bin',
+    '/opt/rh/rh-mysql80/root/usr/libexec',
     '/opt/rh/rh-mysql57/root/usr/bin',
     '/opt/rh/rh-mysql57/root/usr/libexec',
     '/opt/rh/rh-mysql56/root/usr/bin',
@@ -17,6 +21,10 @@ Puppet::Type.type(:mysql_datadir).provide(:mysql, parent: Puppet::Provider::Mysq
     '/opt/rh/rh-mariadb101/root/usr/libexec',
     '/opt/rh/rh-mariadb100/root/usr/bin',
     '/opt/rh/rh-mariadb100/root/usr/libexec',
+    '/opt/rh/rh-mariadb102/root/usr/bin',
+    '/opt/rh/rh-mariadb102/root/usr/libexec',
+    '/opt/rh/rh-mariadb103/root/usr/bin',
+    '/opt/rh/rh-mariadb103/root/usr/libexec',
     '/opt/rh/mysql55/root/usr/bin',
     '/opt/rh/mysql55/root/usr/libexec',
     '/opt/rh/mariadb55/root/usr/bin',
@@ -39,9 +47,8 @@ Puppet::Type.type(:mysql_datadir).provide(:mysql, parent: Puppet::Provider::Mysq
     log_error                = @resource.value(:log_error) || '/var/tmp/mysqld_initialize.log'
     # rubocop:enable Lint/UselessAssignment
     unless defaults_extra_file.nil?
-      unless File.exist?(defaults_extra_file)
-        raise ArgumentError, _('Defaults-extra-file %{file} is missing.') % { file: defaults_extra_file }
-      end
+      raise ArgumentError, _('Defaults-extra-file %{file} is missing.') % { file: defaults_extra_file } unless File.exist?(defaults_extra_file)
+
       defaults_extra_file = "--defaults-extra-file=#{defaults_extra_file}"
     end
 
@@ -57,10 +64,7 @@ Puppet::Type.type(:mysql_datadir).provide(:mysql, parent: Puppet::Provider::Mysq
       opts << "--#{opt}=#{val}" unless val.nil?
     end
 
-    if mysqld_version.nil?
-      debug("Installing MySQL data directory with mysql_install_db #{opts.compact.join(' ')}")
-      mysql_install_db(opts.compact)
-    elsif newer_than('mysql' => '5.7.6', 'percona' => '5.7.6')
+    if !mysqld_version.nil? && newer_than('mysql' => '5.7.6', 'percona' => '5.7.6')
       opts << "--log-error=#{log_error}"
       opts << initialize.to_s
       debug("Initializing MySQL data directory >= 5.7.6 with mysqld: #{opts.compact.join(' ')}")
