@@ -1,4 +1,6 @@
 #!/opt/puppetlabs/puppet/bin/ruby
+# frozen_string_literal: true
+
 require 'json'
 require 'open3'
 require 'puppet'
@@ -9,12 +11,13 @@ def get(file, database, user, password)
   cmd_string << " --user=#{user}" unless user.nil?
   cmd_string << " --password=#{password}" unless password.nil?
   cmd_string << " > #{file}" unless file.nil?
-  stdout, _stderr, status = Open3.capture3(cmd_string)
-  raise Puppet::Error, _("stderr: ' %{stderr}') % { stderr: stderr }") if status != 0
+  stdout, stderr, status = Open3.capture3(cmd_string)
+  raise Puppet::Error, _("stderr: '%{stderr}'" % { stderr: stderr }) if status != 0
+
   { status: stdout.strip }
 end
 
-params = JSON.parse(STDIN.read)
+params = JSON.parse($stdin.read)
 database = params['database']
 user = params['user']
 password = params['password']
