@@ -1,4 +1,6 @@
 #!/opt/puppetlabs/puppet/bin/ruby
+# frozen_string_literal: true
+
 require 'json'
 require 'open3'
 require 'puppet'
@@ -8,12 +10,13 @@ def get(sql, database, user, password)
   cmd << "--database=#{database}" unless database.nil?
   cmd << "--user=#{user}" unless user.nil?
   cmd << "--password=#{password}" unless password.nil?
-  stdout, stderr, status = Open3.capture3(*cmd) # rubocop:disable Lint/UselessAssignment
-  raise Puppet::Error, _("stderr: ' %{stderr}') % { stderr: stderr }") if status != 0
+  stdout, stderr, status = Open3.capture3(*cmd)
+  raise Puppet::Error, _("stderr: '%{stderr}'" % { stderr: stderr }) if status != 0
+
   { status: stdout.strip }
 end
 
-params = JSON.parse(STDIN.read)
+params = JSON.parse($stdin.read)
 database = params['database']
 user = params['user']
 password = params['password']
